pub fn read_bundle(path: impl AsRef<Path>) -> Result<ResultBundle>Expand description
Opens and validates a complete bundle manifest without eagerly loading scientific arrays.
pub fn read_bundle(path: impl AsRef<Path>) -> Result<ResultBundle>Opens and validates a complete bundle manifest without eagerly loading scientific arrays.